==> edgeimpulse-0.0.7.tar.gz: edgeimpulse-0.0.7/edgeimpulse/camera.py <==
#!/usr/bin/env python

import numpy as np
import cv2
from edgeimpulse.runner import ImpulseRunner

class CameraImpulseRunner(ImpulseRunner):
    def __init__(self, model_path: str):
        super(CameraImpulseRunner, self).__init__(model_path)
        self.closed = True
        self.labels = []
        self.dim = (0, 0)
        self.videoCapture = cv2.VideoCapture()

    def init(self):
        model_info = super(CameraImpulseRunner, self).init()

        width = model_info['model_parameters']['image_input_width'];
        height = model_info['model_parameters']['image_input_height'];

        if width == 0 or height == 0:
            raise Exception('Model file "' + self._model_path + '" is not suitable for image recognition')

        self.dim = (width, height)
        self.labels = model_info['model_parameters']['labels']
        return model_info

    def __enter__(self):
        self.closed = False
        return self

    def __exit__(self, type, value, traceback):
        self.videoCapture.release()
        self.closed = True

    def classify(self):
        self.videoCapture.open(0)
        while not self.closed:
            # Capture frame-by-frame
            ret, brg = self.videoCapture.read()
            if ret:
                resizedImg = cv2.resize(brg, self.dim, interpolation = cv2.INTER_AREA)
                features = np.array(resizedImg).flatten().tolist()
                res = super(CameraImpulseRunner, self).classify(features)
                yield res, brg

==> edgeimpulse-0.0.8.tar.gz: edgeimpulse-0.0.8/edgeimpulse/camera.py <==
#!/usr/bin/env python

import numpy as np
import cv2
from edgeimpulse.runner import ImpulseRunner
import time

class CameraImpulseRunner(ImpulseRunner):
    def __init__(self, model_path: str):
        super(CameraImpulseRunner, self).__init__(model_path)
        self.closed = True
        self.labels = []
        self.dim = (0, 0)
        self.videoCapture = cv2.VideoCapture()

    def init(self):
        model_info = super(CameraImpulseRunner, self).init()

        width = model_info['model_parameters']['image_input_width'];
        height = model_info['model_parameters']['image_input_height'];

        if width == 0 or height == 0:
            raise Exception('Model file "' + self._model_path + '" is not suitable for image recognition')

        self.dim = (width, height)
        self.labels = model_info['model_parameters']['labels']
        return model_info

    def __enter__(self):
        self.videoCapture.open(0)
        self.closed = False
        return self

    def __exit__(self, type, value, traceback):
        self.videoCapture.release()
        self.closed = True

    def classify(self):
        while not self.closed and self.videoCapture.isOpened():
            ret, brg = self.videoCapture.read()
            print(ret)
            if ret:
                gray = cv2.cvtColor(brg, cv2.COLOR_BGR2GRAY)
                resizedImg = cv2.resize(gray, self.dim, interpolation = cv2.INTER_AREA)
                features = np.array(resizedImg).flatten().tolist()
                res = super(CameraImpulseRunner, self).classify(features)
                yield res, brg
